@@ -598,27 +598,45 @@ void MoveClipCommand::redo()
             setText(QObject::tr("Move timeline clip"));
     }
     QList<QPoint> selection;
-    if (m_ripple && !m_trackDelta && m_clips.size() == 1) {
-        auto mlt_index = m_model.trackList().at(m_clips.first().trackIndex).mlt_index;
+    if (!m_trackDelta && m_clips.size() == 1) {
+        auto trackIndex = m_clips.first().trackIndex;
+        auto mlt_index = m_model.trackList().at(trackIndex).mlt_index;
         QScopedPointer<Mlt::Producer> track(m_model.tractor()->track(mlt_index));
         if (track) {
             Mlt::Playlist playlist(*track);
             int newStart = m_clips.first().start + m_positionDelta;
             auto targetIndex = playlist.get_clip_index_at(newStart);
-            if (targetIndex >= m_clips.first().clipIndex || // pushing clips on same track
+            auto clipIndex = m_clips.first().clipIndex;
+            if (targetIndex >= clipIndex || // pushing clips on same track
                     // pulling clips on same track
-                    (playlist.is_blank_at(newStart) && targetIndex == m_clips.first().clipIndex - 1)) {
-                // Use old behavior to push or pull clips on the same track.
-                m_model.moveClip(m_clips.first().trackIndex, m_clips.first().trackIndex, m_clips.first().clipIndex,
-                                 newStart, m_ripple, m_rippleAllTracks);
-                if (!m_redo) {
-                    m_redo = true;
-                    m_undoHelper.recordAfterState();
+                    (playlist.is_blank_at(newStart) && targetIndex == clipIndex - 1)) {
+                bool done = true;
+                if (targetIndex == clipIndex && m_model.isTransition(playlist, clipIndex - 1)) {
+                    // Increase duration of transition
+                    m_model.trimTransitionOut(trackIndex, clipIndex, m_positionDelta, true);
+                    if (!m_ripple)
+                        m_model.trimClipIn(trackIndex, clipIndex + 1, m_positionDelta, true, false);
+                } else if (m_ripple) {
+                    // Push or pull clips on the same track
+                    m_model.moveClip(trackIndex, trackIndex, clipIndex, newStart, m_ripple,
+                                     m_rippleAllTracks);
+                } else if (m_model.isTransition(playlist, clipIndex + 1)) {
+                    // Increase duration of transition
+                    m_model.trimTransitionIn(trackIndex, clipIndex, -m_positionDelta, true);
+                    m_model.trimClipOut(trackIndex, clipIndex - 1, -m_positionDelta, true, false);
+                } else {
+                    done = false;
+                }
+                if (done) {
+                    if (!m_redo) {
+                        m_redo = true;
+                        m_undoHelper.recordAfterState();
+                    }
+                    redoMarkers();
+                    selection = m_timeline.uuidsToSelection(QVector<QUuid>() << m_clips.first().uuid);
+                    m_timeline.setSelection(selection);
+                    return;
                 }
-                redoMarkers();
-                selection = m_timeline.uuidsToSelection(QVector<QUuid>() << m_clips.first().uuid);
-                m_timeline.setSelection(selection);
-                return;
             }
         }
     }
@@ -1475,12 +1493,15 @@ void AddTrackCommand::redo()
     else
         m_trackIndex = m_model.addAudioTrack();
     int mlt_index = m_model.trackList().at(m_trackIndex).mlt_index;
-    Mlt::Producer producer(m_model.tractor()->multitrack()->track(mlt_index));
-    if (producer.is_valid()) {
+    std::unique_ptr<Mlt::Multitrack> multitrack(m_model.tractor()->multitrack());
+    if (!multitrack || !multitrack->is_valid())
+        return;
+    std::unique_ptr<Mlt::Producer> producer(multitrack->track(mlt_index));
+    if (producer && producer->is_valid()) {
         if (m_uuid.isNull()) {
-            m_uuid = MLT.ensureHasUuid(producer);
+            m_uuid = MLT.ensureHasUuid(*producer);
         } else {
-            MLT.setUuid(producer, m_uuid);
+            MLT.setUuid(*producer, m_uuid);
         }
     }
 }
@@ -1514,12 +1535,15 @@ void InsertTrackCommand::redo()
                                                               "video");
     m_model.insertTrack(m_trackIndex, m_trackType);
     int mlt_index = m_model.trackList().at(m_trackIndex).mlt_index;
-    Mlt::Producer producer(m_model.tractor()->multitrack()->track(mlt_index));
-    if (producer.is_valid()) {
+    std::unique_ptr<Mlt::Multitrack> multitrack(m_model.tractor()->multitrack());
+    if (!multitrack || !multitrack->is_valid())
+        return;
+    std::unique_ptr<Mlt::Producer> producer(multitrack->track(mlt_index));
+    if (producer && producer->is_valid()) {
         if (m_uuid.isNull()) {
-            m_uuid = MLT.ensureHasUuid(producer);
+            m_uuid = MLT.ensureHasUuid(*producer);
         } else {
-            MLT.setUuid(producer, m_uuid);
+            MLT.setUuid(*producer, m_uuid);
         }
     }
 }
@@ -1821,12 +1845,15 @@ void DetachAudioCommand::redo()
         if (m_targetTrackIndex > -1) {
             // Set the producer UUID on the new track.
             int mlt_index = model->trackList().at(m_targetTrackIndex).mlt_index;
-            Mlt::Producer producer(model->tractor()->multitrack()->track(mlt_index));
-            if (producer.is_valid()) {
-                if (m_uuid.isNull()) {
-                    m_uuid = MLT.ensureHasUuid(producer);
-                } else {
-                    MLT.setUuid(producer, m_uuid);
+            std::unique_ptr<Mlt::Multitrack> multitrack(model->tractor()->multitrack());
+            if (multitrack && !multitrack->is_valid()) {
+                std::unique_ptr<Mlt::Producer> producer(multitrack->track(mlt_index));
+                if (producer && producer->is_valid()) {
+                    if (m_uuid.isNull()) {
+                        m_uuid = MLT.ensureHasUuid(*producer);
+                    } else {
+                        MLT.setUuid(*producer, m_uuid);
+                    }
                 }
             }
             m_undoHelper.recordBeforeState();
@@ -1942,7 +1969,7 @@ void AlignClipsCommand::redo()
         if (alignment.speed != 1.0) {
             double warpspeed = Util::GetSpeedFromProducer(info->producer) * alignment.speed;
             QString filename = Util::GetFilenameFromProducer(info->producer, false);
-            QString s = QString("%1:%2:%3").arg("timewarp").arg(warpspeed).arg(filename);
+            QString s = QStringLiteral("%1:%2:%3").arg("timewarp").arg(warpspeed).arg(filename);
             item.clip = new Mlt::Producer(MLT.profile(), s.toUtf8().constData());
             if (!item.clip || !item.clip->is_valid()) {
                 delete item.clip;
