@@ -28,6 +28,7 @@
 #include <MltProperties.h>
 
 class QTreeWidgetItem;
+class QTemporaryFile;
 namespace Ui {
 class EncodeDock;
 }
@@ -36,6 +37,7 @@ class MeltJob;
 namespace Mlt {
 class Service;
 class Producer;
+class Filter;
 }
 
 class PresetsProxyModel : public QSortFilterProxyModel
@@ -57,11 +59,13 @@ public:
 
 signals:
     void captureStateChanged(bool);
+    void createOrEditFilterOnOutput(Mlt::Filter *, const QStringList & = {});
 
 public slots:
     void onAudioChannelsChanged();
     void onProducerOpened();
     void onProfileChanged();
+    void onReframeChanged();
     void on_hwencodeButton_clicked();
     bool detectHardwareEncoders();
 
@@ -129,6 +133,12 @@ private slots:
 
     void on_resolutionComboBox_activated(int arg1);
 
+    void on_reframeButton_clicked();
+
+    void on_aspectNumSpinner_valueChanged(int value);
+
+    void on_aspectDenSpinner_valueChanged(int value);
+
 private:
     enum {
         RateControlAverage = 0,
@@ -158,6 +168,11 @@ private:
     void loadPresets();
     Mlt::Properties *collectProperties(int realtime, bool includeProfile = false);
     void collectProperties(QDomElement &node, int realtime);
+    void setSubtitleProperties(QDomElement &node, Mlt::Producer *service);
+    QPoint addConsumerElement(Mlt::Producer *service, QDomDocument &dom, const QString &target,
+                              int realtime, int pass);
+    MeltJob *convertReframe(Mlt::Producer *service, QTemporaryFile *tmp, const QString &target,
+                            int realtime, int pass, const QThread::Priority priority);
     MeltJob *createMeltJob(Mlt::Producer *service, const QString &target, int realtime, int pass = 0,
                            const QThread::Priority priority = Settings.jobPriority());
     void runMelt(const QString &target, int realtime = -1);
@@ -166,11 +181,16 @@ private:
     void encode(const QString &target);
     void resetOptions();
     Mlt::Producer *fromProducer() const;
-    static void filterX265Params(QStringList &other);
+    static void filterCodecParams(const QString &vcodec, QStringList &other);
     void onVideoCodecComboChanged(int index, bool ignorePreset = false, bool resetBframes = true);
     bool checkForMissingFiles();
     QString &defaultFormatExtension();
     void initSpecialCodecLists();
+    void setReframeEnabled(bool enabled);
+    void showResampleWarning(const QString &message);
+    void hideResampleWarning(bool hide = true);
+    void checkFrameRate();
+    void setResolutionAspectFromProfile();
 };
 
 #endif // ENCODEDOCK_H
