@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013-2023 Meltytech, LLC
+ * Copyright (c) 2013-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,6 +25,8 @@
 #include <QDateTime>
 #include "models/markersmodel.h"
 #include "models/multitrackmodel.h"
+#include "models/subtitlesmodel.h"
+#include "models/subtitlesselectionmodel.h"
 #include "sharedframe.h"
 #include "jobs/ffmpegjob.h"
 
@@ -63,6 +65,14 @@ public:
     {
         return & m_markersModel;
     }
+    SubtitlesModel *subtitlesModel()
+    {
+        return & m_subtitlesModel;
+    }
+    SubtitlesSelectionModel *subtitlesSelectionModel()
+    {
+        return & m_subtitlesSelectionModel;
+    }
     int position() const
     {
         return m_position;
@@ -125,7 +135,7 @@ signals:
     void currentTrackChanged();
     void selectionChanged();
     void seeked(int position);
-    void positionChanged();
+    void positionChanged(int position);
     void loopChanged();
     void clipOpened(Mlt::Producer *producer);
     void dragging(const QPointF &pos, int duration);
@@ -160,9 +170,9 @@ public slots:
     void onShowFrame(const SharedFrame &frame);
     void onSeeked(int position);
     void append(int trackIndex);
-    void remove(int trackIndex, int clipIndex);
+    void remove(int trackIndex, int clipIndex, bool ignoreTransition = false);
     bool mergeClipWithNext(int trackIndex, int clipIndex, bool dryrun);
-    void lift(int trackIndex, int clipIndex);
+    void lift(int trackIndex, int clipIndex, bool ignoreTransition = false);
     void removeSelection(bool withCopy = false);
     void liftSelection();
     void incrementCurrentTrack(int by);
@@ -180,7 +190,7 @@ public slots:
     bool trimClipOut(int trackIndex, int clipIndex, int delta, bool ripple);
     void insert(int trackIndex, int position = -1, const QString &xml = QString(), bool seek = true);
     void overwrite(int trackIndex, int position = -1, const QString &xml = QString(), bool seek = true);
-    void appendFromPlaylist(Mlt::Playlist *playlist, bool skipProxy);
+    void appendFromPlaylist(Mlt::Playlist *playlist, bool skipProxy, bool emptyTrack);
     void fadeIn(int trackIndex, int clipIndex = -1, int duration = -1);
     void fadeOut(int trackIndex, int clipIndex = -1, int duration = -1);
     void seekPreviousEdit();
@@ -234,6 +244,7 @@ private:
     bool isBlank(int trackIndex, int clipIndex);
     bool clipsAreSelected();
     bool blankIsSelected();
+    bool nothingIsSelected();
     bool isTransition(int trackIndex, int clipIndex);
     void emitNonSeekableWarning();
     void addTrackIfNeeded(int mltTrackIndex, Mlt::Producer *srcTrack);
@@ -244,10 +255,13 @@ private:
     }
     void reportSelectionChange();
     void applyCopiedFiltersToSelectdClips();
+    void insertOrOverwriteDrop(int trackIndex, int position, const QString &xml);
 
     QQuickWidget m_quickView;
     MultitrackModel m_model;
     MarkersModel m_markersModel;
+    SubtitlesModel m_subtitlesModel;
+    SubtitlesSelectionModel m_subtitlesSelectionModel;
     int m_position;
     std::unique_ptr<Timeline::UpdateCommand> m_updateCommand;
     bool m_ignoreNextPositionChange;
@@ -283,7 +297,7 @@ private slots:
     void onTransitionAdded(int trackIndex, int clipIndex, int position, bool ripple);
     void selectClip(int trackIndex, int clipIndex);
     void onMultitrackClosed();
-    void reloadTimelineMarkers();
+    void reloadTimelineModels();
     void onRecordStarted();
     void updateRecording();
     void onRecordFinished(AbstractJob *, bool);
