@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Meltytech, LLC
+ * Copyright (c) 2018-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,7 @@
 #include "postjobaction.h"
 #include "mainwindow.h"
 #include "docks/playlistdock.h"
+#include "docks/subtitlesdock.h"
 #include "shotcut_mlt_properties.h"
 #include <Logger.h>
 
@@ -88,6 +89,7 @@ void ProxyReplacePostJobAction::doAction()
     FilePropertiesPostJobAction::doAction();
     QFileInfo info(m_dstFile);
     QString newFileName = info.path() + "/" + info.baseName() + "." + info.suffix();
+    QFile::remove(newFileName);
     if (QFile::rename(m_dstFile, newFileName)) {
         Mlt::Producer newProducer(MLT.profile(), newFileName.toUtf8().constData());
         if (newProducer.is_valid()) {
@@ -116,3 +118,9 @@ void ProxyFinalizePostJobAction::doAction()
         QFile::remove(m_dstFile);
     }
 }
+
+
+void ImportSrtPostJobAction::doAction()
+{
+    m_dock->importSrtFromFile(m_srtFile, m_trackName, m_lang, m_includeNonspoken);
+}
