@@ -35,7 +35,8 @@
 #endif
 
 #ifdef Q_OS_WIN
-#ifdef QT_DEBUG
+#include <windows.h>
+#if defined(QT_DEBUG) && !defined(__ARM_ARCH)
 #   include <exchndl.h>
 #endif
 extern "C"
@@ -82,11 +83,11 @@ static void mlt_log_handler(void *service, int mlt_level, const char *format, va
         if (!resource || resource[0] != '<' || resource[strlen(resource) - 1] != '>')
             mlt_type = mlt_properties_get(properties, "mlt_type" );
         if (service_name)
-            message = QString("[%1 %2] ").arg(mlt_type, service_name);
+            message = QStringLiteral("[%1 %2] ").arg(mlt_type, service_name);
         else
             message = QString::asprintf("[%s %p] ", mlt_type, service);
         if (resource)
-            message.append(QString("\"%1\" ").arg(resource));
+            message.append(QStringLiteral("\"%1\" ").arg(resource));
         message.append(QString::vasprintf(format, args));
         message.replace('\n', "");
     } else {
@@ -222,7 +223,9 @@ public:
         // Startup logging.
         dir.setPath(Settings.appDataLocation());
         if (!dir.exists()) dir.mkpath(dir.path());
-        QFile::copy(dir.filePath("shotcut-log.txt"), dir.filePath("shotcut-log.bak"));
+        auto previousLogName = dir.filePath("shotcut-log.bak");
+        QFile::remove(previousLogName);
+        QFile::copy(dir.filePath("shotcut-log.txt"), previousLogName);
         const QString logFileName = dir.filePath("shotcut-log.txt");
         QFile::remove(logFileName);
         FileAppender *fileAppender = new FileAppender(logFileName);
@@ -301,7 +304,7 @@ protected:
 
 int main(int argc, char **argv)
 {
-#if defined(Q_OS_WIN) && defined(QT_DEBUG)
+#if defined(Q_OS_WIN) && defined(QT_DEBUG) && !defined(__ARM_ARCH)
     ExcHndlInit();
 #endif
 #ifndef QT_DEBUG
@@ -331,13 +334,32 @@ int main(int argc, char **argv)
         }
     }
 #endif
+
+    // The ffmpeg backend (default as of Qt 6.5) is likely using a different version of FFmpeg.
+    if (!qEnvironmentVariableIsSet("QT_MEDIA_BACKEND"))
+#if defined(Q_OS_MAC)
+        qputenv("QT_MEDIA_BACKEND", "darwin");
+#elif defined(Q_OS_WIN)
+        qputenv("QT_MEDIA_BACKEND", "windows");
+    if (!qEnvironmentVariableIsSet("QT_QPA_PLATFORM"))
+        qputenv("QT_QPA_PLATFORM", "windows:altgr");
+
+    // The modern Windows style adopted in Qt 6.7 changes spinboxes to have
+    // larger arrow buttons side-by-side thus making the numeric area
+    // smaller and incompatible with every other combination of style and OS.
+    if (!qEnvironmentVariableIsSet("QT_STYLE_OVERRIDE"))
+        qputenv("QT_STYLE_OVERRIDE", "windowsvista");
+#else
+        ;
+#endif
+
 #ifdef Q_OS_MAC
     // Launcher and Spotlight on macOS are not setting this environment
     // variable needed by setlocale() as used by MLT.
     if (QProcessEnvironment::systemEnvironment().value(MLT_LC_NAME).isEmpty()) {
         qputenv(MLT_LC_NAME, QLocale().name().toUtf8());
 
-        QLocale localeByName(QLocale(QLocale().language(), QLocale().script(), QLocale().country()));
+        QLocale localeByName(QLocale(QLocale().language(), QLocale().script(), QLocale().territory()));
         if (QLocale().decimalPoint() != localeByName.decimalPoint()) {
             // If region's numeric format does not match the language's, then we run
             // into problems because we told MLT and libc to use a different numeric
