@@ -51,6 +51,7 @@ class QNetworkReply;
 class KeyframesDock;
 class MarkersDock;
 class NotesDock;
+class SubtitlesDock;
 
 class MainWindow : public QMainWindow
 {
@@ -79,6 +80,10 @@ public:
     {
         return m_playlistDock;
     }
+    TimelineDock *timelineDock() const
+    {
+        return m_timelineDock;
+    }
     FilterController *filterController() const
     {
         return m_filterController;
@@ -89,7 +94,6 @@ public:
     bool isMultitrackValid() const;
     void doAutosave();
     void setFullScreen(bool isFullScreen);
-    QString removeFileScheme(QUrl &url);
     QString untitledFileName() const;
     void setProfile(const QString &profile_name);
     QString fileName() const
@@ -112,7 +116,8 @@ public:
     {
         return m_profileGroup;
     }
-    void buildVideoModeMenu(QMenu *topMenu, QMenu *&customMenu, QActionGroup *group, QAction *addAction,
+    void buildVideoModeMenu(QMenu *topMenu, QMenu *&customMenu, QActionGroup *group,
+                            QAction *addAction,
                             QAction *removeAction);
     void newProject(const QString &filename, bool isProjectFolder = false);
     void addCustomProfile(const QString &name, QMenu *menu, QAction *action, QActionGroup *group);
@@ -186,6 +191,7 @@ private:
     void restartAfterChangeTheme();
     void backup();
     void backupPeriodically();
+    bool confirmProfileChange();
 
     Ui::MainWindow *ui;
     Player *m_player;
@@ -225,6 +231,7 @@ private:
     QDateTime m_sourceUpdatedAt;
     MarkersDock *m_markersDock;
     NotesDock *m_notesDock;
+    SubtitlesDock *m_subtitlesDock;
     std::unique_ptr<QWidget> m_producerWidget;
 
 public slots:
@@ -251,6 +258,8 @@ public slots:
     void onShuttle(float x);
     void onPropertiesDockTriggered(bool checked = true);
     bool on_actionSave_triggered();
+    void onCreateOrEditFilterOnOutput(Mlt::Filter *filter, const QStringList &key_properties);
+    void showSettingsMenu() const;
 
 private slots:
     void showUpgradePrompt();
@@ -269,6 +278,7 @@ private slots:
     void onKeyframesDockTriggered(bool checked = true);
     void onMarkersDockTriggered(bool = true);
     void onNotesDockTriggered(bool = true);
+    void onSubtitlesDockTriggered(bool = true);
     void onPlaylistCreated();
     void onPlaylistLoaded();
     void onPlaylistCleared();
@@ -279,6 +289,7 @@ private slots:
     void onMultitrackModified();
     void onMultitrackDurationChanged();
     void onNoteModified();
+    void onSubtitleModified();
     void onCutModified();
     void onProducerModified();
     void onFilterModelChanged();
@@ -327,12 +338,13 @@ private slots:
     void on_menuExternal_aboutToShow();
     void on_actionUpgrade_triggered();
     void on_actionOpenXML_triggered();
+    void on_actionShowProjectFolder_triggered();
     void onAutosaveTimeout();
     void onFocusChanged(QWidget *old, QWidget *now) const;
     void onFocusObjectChanged(QObject *obj) const;
     void onFocusWindowChanged(QWindow *window) const;
     void onTimelineClipSelected();
-    void onAddAllToTimeline(Mlt::Playlist *playlist, bool skipProxy);
+    void onAddAllToTimeline(Mlt::Playlist *playlist, bool skipProxy, bool emptyTrack);
     void on_actionScrubAudio_triggered(bool checked);
 #if !defined(Q_OS_MAC)
     void onDrawingMethodTriggered(QAction *);
