@@ -148,19 +148,12 @@ int Controller::open(const QString &url, const QString &urlToSave, bool skipConv
         }
         updatePreviewProfile();
         setPreviewScale(Settings.playerPreviewScale());
-        if ( url.endsWith(".mlt") ) {
+        if (url.endsWith(".mlt")) {
             // Load the number of audio channels being used when this project was created.
             int channels = newProducer->get_int(kShotcutProjectAudioChannels);
             if (!channels)
                 channels = 2;
             m_audioChannels = channels;
-            if (newProducer->get_int(kShotcutProjectFolder)) {
-                QFileInfo info(url);
-                setProjectFolder(info.absolutePath());
-                ProxyManager::removePending();
-            } else {
-                setProjectFolder(QString());
-            }
         }
         if (Util::isFpsDifferent(profile().fps(), fps) || (Settings.playerGPU()
                                                            && !profile().is_explicit())) {
@@ -438,7 +431,7 @@ void Controller::setVolume(double volume, bool muteOnPause)
     }
 
     if (m_consumer) {
-        if (m_consumer->get("mlt_service") == QString("multi")) {
+        if (m_consumer->get("mlt_service") == QStringLiteral("multi")) {
             m_consumer->set("0.volume", volume);
         } else {
             m_consumer->set("volume", volume);
@@ -514,7 +507,7 @@ bool Controller::saveXML(const QString &filename, Service *service, bool withRel
         c.set("store", "shotcut");
         c.set("root", root.toUtf8().constData());
         c.set("no_root", 1);
-        c.set("title", QString("Shotcut version ").append(SHOTCUT_VERSION).toUtf8().constData());
+        c.set("title", QStringLiteral("Shotcut version ").append(SHOTCUT_VERSION).toUtf8().constData());
         c.connect(s);
         c.start();
         if (ignore)
@@ -598,7 +591,8 @@ void Controller::setProfile(const QString &profile_name)
     if (!profile_name.isEmpty()) {
         Mlt::Profile tmp(profile_name.toUtf8().constData());
         m_profile.set_colorspace(tmp.colorspace());
-        m_profile.set_frame_rate(tmp.frame_rate_num(), tmp.frame_rate_den());
+        auto gcd = Util::greatestCommonDivisor(tmp.frame_rate_num(), tmp.frame_rate_den());
+        m_profile.set_frame_rate(tmp.frame_rate_num() / gcd, tmp.frame_rate_den() / gcd);
         m_profile.set_height(Util::coerceMultiple(tmp.height()));
         m_profile.set_progressive(tmp.progressive());
         m_profile.set_sample_aspect(tmp.sample_aspect_num(), tmp.sample_aspect_den());
@@ -818,6 +812,95 @@ void Controller::setOut(int out)
     }
 }
 
+class FixLengthPropertiesParser : public Mlt::Parser
+{
+public:
+    FixLengthPropertiesParser() : Mlt::Parser() {}
+
+    int on_start_filter(Mlt::Filter *)
+    {
+        return 0;
+    }
+    int on_start_producer(Mlt::Producer *)
+    {
+        return 0;
+    }
+    int on_end_producer(Mlt::Producer *s)
+    {
+        if (!::strchr(s->get("length"), ':'))
+            s->set("length", s->frames_to_time(s->get_int("length"), mlt_time_clock));
+        return 0;
+    }
+    int on_start_playlist(Mlt::Playlist *)
+    {
+        return 0;
+    }
+    int on_end_playlist(Mlt::Playlist *)
+    {
+        return 0;
+    }
+    int on_start_tractor(Mlt::Tractor *)
+    {
+        return 0;
+    }
+    int on_end_tractor(Mlt::Tractor *)
+    {
+        return 0;
+    }
+    int on_start_multitrack(Mlt::Multitrack *)
+    {
+        return 0;
+    }
+    int on_end_multitrack(Mlt::Multitrack *)
+    {
+        return 0;
+    }
+    int on_start_track()
+    {
+        return 0;
+    }
+    int on_end_track()
+    {
+        return 0;
+    }
+    int on_end_filter(Mlt::Filter *)
+    {
+        return 0;
+    }
+    int on_start_transition(Mlt::Transition *)
+    {
+        return 0;
+    }
+    int on_end_transition(Mlt::Transition *)
+    {
+        return 0;
+    }
+    int on_start_chain(Mlt::Chain *)
+    {
+        return 0;
+    }
+    int on_end_chain(Mlt::Chain *s)
+    {
+        if (!::strchr(s->get("length"), ':'))
+            s->set("length", s->frames_to_time(s->get_int("length"), mlt_time_clock));
+        return 0;
+    }
+    int on_start_link(Mlt::Link *)
+    {
+        return 0;
+    }
+    int on_end_link(Mlt::Link *)
+    {
+        return 0;
+    }
+};
+
+void Controller::fixLengthProperties(Service &service)
+{
+    FixLengthPropertiesParser parser;
+    parser.start(service);
+}
+
 void Controller::restart(const QString &xml)
 {
     if (!m_consumer || !m_consumer->is_valid() || !m_producer || !m_producer->is_valid())
@@ -985,7 +1068,7 @@ Producer *Controller::setupNewProducer(Producer *newProducer) const
             int i = 0;
             QScopedPointer<Mlt::Filter> filter(newProducer->filter(i));
             while (filter && filter->is_valid()) {
-                if (!filter->get_int("_loader")) {
+                if (!filter->get_int("_loader") && !filter->get_int(kShotcutHiddenProperty)) {
                     newProducer->detach(*filter);
                     chain->Service::attach(*filter);
                 } else {
@@ -1020,6 +1103,30 @@ QUuid Controller::ensureHasUuid(Mlt::Properties &properties) const
     return newUid;
 }
 
+static int indexOfFirstNonGpu(Producer &toProducer)
+{
+    for (int i = 0; i < toProducer.filter_count(); i++) {
+        QScopedPointer<Mlt::Filter> filter(toProducer.filter(i));
+        if (filter && filter->is_valid() && !filter->get_int("_loader")
+                && !filter->get_int(kShotcutHiddenProperty)
+                && filter->get("mlt_service")) {
+            if (!QString::fromLatin1(filter->get("mlt_service")).startsWith("movit."))
+                return i;
+        }
+    }
+    Mlt::Chain toChain(toProducer);
+    for (int i = 0; i < toChain.link_count(); i++) {
+        QScopedPointer<Mlt::Link> link(toChain.link(i));
+        if (link && link->is_valid() && !link->get_int("_loader")
+                && !link->get_int(kShotcutHiddenProperty)
+                && link->get("mlt_service")) {
+            if (!QString::fromLatin1(link->get("mlt_service")).startsWith("movit."))
+                return i;
+        }
+    }
+    return -1;
+}
+
 void Controller::copyFilters(Producer &fromProducer, Producer &toProducer, bool fromClipboard,
                              bool includeDisabled)
 {
@@ -1029,9 +1136,13 @@ void Controller::copyFilters(Producer &fromProducer, Producer &toProducer, bool
                   kFilterOutProperty) : fromProducer.get_out();
     int count = fromProducer.filter_count();
 
+    // Get the index of the first non-GPU filter or link in toProducer
+    int firstNonGpuService = fromClipboard ? indexOfFirstNonGpu(toProducer) : -1;
+
     for (int i = 0; i < count; i++) {
         QScopedPointer<Mlt::Filter> fromFilter(fromProducer.filter(i));
         if (fromFilter && fromFilter->is_valid() && !fromFilter->get_int("_loader")
+                && !fromFilter->get_int(kShotcutHiddenProperty)
                 && fromFilter->get("mlt_service")
                 && (includeDisabled || !fromFilter->get_int("disable"))) {
 
@@ -1056,6 +1167,8 @@ void Controller::copyFilters(Producer &fromProducer, Producer &toProducer, bool
                 // Force any 2-pass filters to require re-analysis
                 toFilter.clear("results");
                 toProducer.attach(toFilter);
+                if (firstNonGpuService >= 0 && metadata->needsGPU())
+                    toProducer.move_filter(toProducer.filter_count(), firstNonGpuService++);
 
                 if (!fromClipboard) {
                     toFilter.set(kFilterInProperty, fromFilter->get_in() - in);
@@ -1079,6 +1192,9 @@ void Controller::copyFilters(Producer &fromProducer, Producer &toProducer, bool
                 if (toLink.is_valid()) {
                     toLink.inherit(*fromLink);
                     toChain.attach(toLink);
+                    if (firstNonGpuService >= 0
+                            && QString::fromLatin1(fromLink->get("mlt_service")).startsWith("movit."))
+                        toChain.move_link(toChain.link_count(), firstNonGpuService++);
                 }
             }
         }
@@ -1132,7 +1248,7 @@ void Controller::adjustFilters(Producer &producer, int index)
                 // Convert legacy fadeIn filters.
                 filter->set(kShotcutAnimOutProperty, filter->get_length());
             }
-            if (!filter->get_int("_loader")) {
+            if (!filter->get_int("_loader") && !filter->get_int(kShotcutHiddenProperty)) {
                 int filterIn = in;
                 int filterOut = out;
                 if (filter->get(kFilterInProperty))
@@ -1311,7 +1427,8 @@ void Controller::adjustFilter(Mlt::Filter *filter, int in, int out, int inDelta,
                 filter->anim_set("level", -60, filter->get_length() - 1);
             }
             emit MAIN.serviceInChanged(inDelta, filter);
-        } else if (!filter->get_int("_loader") && filter->get_in() <= in) {
+        } else if (!filter->get_int("_loader") && !filter->get_int(kShotcutHiddenProperty)
+                   && filter->get_in() <= in) {
             filter->set_in_and_out(in + inDelta, filter->get_out());
             emit MAIN.serviceInChanged(inDelta, filter);
         }
@@ -1340,7 +1457,8 @@ void Controller::adjustFilter(Mlt::Filter *filter, int in, int out, int inDelta,
                 filter->anim_set("level", -60, filter->get_length() - 1);
             }
             emit MAIN.serviceOutChanged(outDelta, filter);
-        } else if (!filter->get_int("_loader")  && filter->get_out() >= out) {
+        } else if (!filter->get_int("_loader") && !filter->get_int(kShotcutHiddenProperty)
+                   && filter->get_out() >= out) {
             filter->set_in_and_out(filter->get_in(), out - outDelta);
             emit MAIN.serviceOutChanged(outDelta, filter);
 
@@ -1524,11 +1642,11 @@ bool Controller::fullRange(Producer &producer)
 {
     bool full = !qstrcmp(producer.get("meta.media.color_range"), "full");
     for (int i = 0; !full && i < producer.get_int("meta.media.nb_streams"); i++) {
-        QString key = QString("meta.media.%1.stream.type").arg(i);
+        QString key = QStringLiteral("meta.media.%1.stream.type").arg(i);
         QString streamType(producer.get(key.toLatin1().constData()));
         if (streamType == "video") {
             if (i == producer.get_int("video_index")) {
-                key = QString("meta.media.%1.codec.pix_fmt").arg(i);
+                key = QStringLiteral("meta.media.%1.codec.pix_fmt").arg(i);
                 QString pix_fmt = QString::fromLatin1(producer.get(key.toLatin1().constData()));
                 if (pix_fmt.startsWith("yuvj")) {
                     full = true;
