@@ -60,7 +60,7 @@ static int normalFilterCount(Mlt::Producer *producer)
     if (producer && producer->is_valid()) {
         for (int i = 0; i < producer->filter_count(); i++) {
             Mlt::Filter *filter = producer->filter(i);
-            if (filter->is_valid() && filter->get_int("_loader")) {
+            if (filter->is_valid() && (filter->get_int("_loader") || filter->get_int(kShotcutHiddenProperty))) {
                 count++;
             } else {
                 i = producer->filter_count();
@@ -176,7 +176,7 @@ bool AttachedFiltersModel::isProducerSelected() const
 
 bool AttachedFiltersModel::supportsLinks() const
 {
-    if ( !m_producer.isNull() && m_producer->is_valid()
+    if (!m_producer.isNull() && m_producer->is_valid()
             && m_producer->type() == mlt_service_chain_type ) {
         return true;
     }
@@ -216,7 +216,7 @@ Qt::ItemFlags AttachedFiltersModel::flags(const QModelIndex &index) const
 
 QVariant AttachedFiltersModel::data(const QModelIndex &index, int role) const
 {
-    if ( !m_producer || !m_producer->is_valid()
+    if (!m_producer || !m_producer->is_valid()
             || index.row() >= m_metaList.size())
         return QVariant();
     switch (role ) {
@@ -301,13 +301,29 @@ Mlt::Service AttachedFiltersModel::doGetService(Mlt::Producer &producer, int row
 {
     Mlt::Service service;
     int mltIndex = mltFilterIndex(&producer, row);
-    Mlt::Filter *filter = producer.filter(mltIndex);
-    if (filter && filter->is_valid()) {
-        service = Mlt::Service(filter->get_service());
+    if (mltIndex >= 0) {
+        Mlt::Filter *filter = producer.filter(mltIndex);
+        if (filter && filter->is_valid()) {
+            service = Mlt::Service(filter->get_service());
+        } else {
+            LOG_ERROR() << "Invalid filter index" << row << mltIndex;
+        }
+        delete filter;
     } else {
-        LOG_ERROR() << "Invalid filter index" << row;
+        mltIndex = mltLinkIndex(&producer, row);
+        if (mltIndex >= 0) {
+            Mlt::Chain chain(producer);
+            Mlt::Link *link = chain.link(mltIndex);
+            if (link && link->is_valid()) {
+                service = Mlt::Service(link->get_service());
+            } else {
+                LOG_ERROR() << "Invalid link index" << row << mltIndex;
+            }
+            delete link;
+        } else {
+            LOG_ERROR() << "Invalid service index" << row << mltIndex;
+        }
     }
-    delete filter;
     return service;
 }
 
@@ -498,7 +514,7 @@ int AttachedFiltersModel::add(QmlMetadata *meta)
         }
         for (int i = 0; i < filterSetProducer.filter_count(); i++) {
             Mlt::Filter *filter = filterSetProducer.filter(i);
-            if (filter->is_valid() && !filter->get_int("_loader")) {
+            if (filter->is_valid() && !filter->get_int("_loader") && !filter->get_int(kShotcutHiddenProperty)) {
                 QmlMetadata *tmpMeta = MAIN.filterController()->metadataForService(filter);
                 insertRow = findInsertRow(tmpMeta);
                 if (!meta->objectName().isEmpty())
@@ -529,6 +545,40 @@ int AttachedFiltersModel::add(QmlMetadata *meta)
     return insertRow;
 }
 
+int AttachedFiltersModel::addService(Mlt::Service *service)
+{
+    int insertRow = -1;
+    if (!m_producer) return -1;
+
+    QmlMetadata *meta = MAIN.filterController()->metadataForService(service);
+    if (!meta->allowMultiple()) {
+        for (int i = 0; i < m_metaList.count(); i++) {
+            const QmlMetadata *attachedMeta = m_metaList[i];
+            if (attachedMeta && meta->uniqueId() == attachedMeta->uniqueId()) {
+                emit duplicateAddFailed(i);
+                return -1;
+            }
+        }
+    }
+
+    Mlt::Filter filter(*service);
+    if (filter.is_valid()) {
+        insertRow = findInsertRow(meta);
+        if (!meta->objectName().isEmpty())
+            filter.set(kShotcutFilterProperty, meta->objectName().toUtf8().constData());
+        filter.set_in_and_out(
+            m_producer->get(kFilterInProperty) ? m_producer->get_int(kFilterInProperty) : m_producer->get_in(),
+            m_producer->get(kFilterOutProperty) ? m_producer->get_int(kFilterOutProperty) :
+            m_producer->get_out());
+        if (isSourceClip()) {
+            doAddService(*m_producer, filter, insertRow);
+        } else {
+            MAIN.undoStack()->push(new Filter::AddCommand(*this, meta->name(), filter, insertRow));
+        }
+    }
+    return insertRow;
+}
+
 void AttachedFiltersModel::doAddService(Mlt::Producer &producer, Mlt::Service &service, int row)
 {
     LOG_DEBUG() << row;
@@ -712,11 +762,10 @@ void AttachedFiltersModel::reset(Mlt::Producer *producer)
         count = m_producer->filter_count();
         for (int i = 0; i < count; i++) {
             Mlt::Filter *filter = m_producer->filter(i);
-            if (filter && filter->is_valid()) {
-                if (!filter->get_int("_loader")) {
-                    QmlMetadata *newMeta = MAIN.filterController()->metadataForService(filter);
-                    m_metaList.append(newMeta);
-                }
+            if (filter && filter->is_valid() && !filter->get_int("_loader")
+                    && !filter->get_int(kShotcutHiddenProperty)) {
+                QmlMetadata *newMeta = MAIN.filterController()->metadataForService(filter);
+                m_metaList.append(newMeta);
             }
             delete filter;
         }
