@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012-2023 Meltytech, LLC
+ * Copyright (c) 2012-2024 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -99,14 +99,14 @@ public:
 
     QString cacheKey(int frameNumber)
     {
-        QString time = m_producer.frames_to_time(frameNumber, mlt_time_clock);
+        QString time = m_producer.frames_to_time(frameNumber, Settings.timeFormat());
         // Reduce the precision to centiseconds to increase chance for cache hit
         // without much loss of accuracy.
         time = time.left(time.size() - 1);
         QString key;
         QString resource = m_producer.get(kShotcutHashProperty);
         if (resource.isEmpty()) {
-            key = QString("%1 %2 %3")
+            key = QStringLiteral("%1 %2 %3")
                   .arg(m_producer.get("mlt_service"))
                   .arg(m_producer.get("resource"))
                   .arg(time);
@@ -114,7 +114,7 @@ public:
             hash.addData(key.toUtf8());
             key = hash.result().toHex();
         } else {
-            key = QString("%1 %2").arg(resource).arg(time);
+            key = QStringLiteral("%1 %2").arg(resource).arg(time);
         }
         return key;
     }
@@ -170,7 +170,7 @@ signals:
 
 PlaylistModel::PlaylistModel(QObject *parent)
     : QAbstractTableModel(parent)
-    , m_playlist(0)
+    , m_playlist(nullptr)
     , m_dropRow(-1)
     , m_mode(Invalid)
 {
@@ -182,7 +182,7 @@ PlaylistModel::PlaylistModel(QObject *parent)
 PlaylistModel::~PlaylistModel()
 {
     delete m_playlist;
-    m_playlist = 0;
+    m_playlist = nullptr;
 }
 
 int PlaylistModel::rowCount(const QModelIndex & /*parent*/) const
@@ -241,7 +241,7 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
                         result = Util::baseName(ProxyManager::resource(*info->producer));
                         if (!::qstrcmp(info->producer->get("mlt_service"), "timewarp")) {
                             double speed = ::qAbs(info->producer->get_double("warp_speed"));
-                            result = QString("%1 (%2x)").arg(result).arg(speed);
+                            result = QStringLiteral("%1 (%2x)").arg(result).arg(speed);
                         }
                     }
                     if (result == "<producer>") {
@@ -278,19 +278,20 @@ QVariant PlaylistModel::data(const QModelIndex &index, int role) const
         }
         case FIELD_IN:
             if (info->producer && info->producer->is_valid()) {
-                return QString::fromLatin1(info->producer->frames_to_time(info->frame_in));
+                return QString::fromLatin1(info->producer->frames_to_time(info->frame_in, Settings.timeFormat()));
             } else {
                 return "";
             }
         case FIELD_DURATION:
             if (info->producer && info->producer->is_valid()) {
-                return QString::fromLatin1(info->producer->frames_to_time(info->frame_count));
+                return QString::fromLatin1(info->producer->frames_to_time(info->frame_count,
+                                                                          Settings.timeFormat()));
             } else {
                 return "";
             }
         case FIELD_START:
             if (info->producer && info->producer->is_valid()) {
-                return QString::fromLatin1(info->producer->frames_to_time(info->start));
+                return QString::fromLatin1(info->producer->frames_to_time(info->start, Settings.timeFormat()));
             } else {
                 return "";
             }
@@ -549,7 +550,7 @@ bool PlaylistModel::dropMimeData(const QMimeData *data, Qt::DropAction action, i
     else if (data->hasFormat("application/x-qabstractitemmodeldatalist")) {
         QByteArray encoded = data->data("application/x-qabstractitemmodeldatalist");
         QDataStream stream(&encoded, QIODevice::ReadOnly);
-        QMap<int,  QVariant> roleDataMap;
+        QMap<int, QVariant> roleDataMap;
         while (!stream.atEnd()) {
             int row, col;
             stream >> row >> col >> roleDataMap;
@@ -627,7 +628,7 @@ void PlaylistModel::load()
     m_playlist = new Mlt::Playlist(*MLT.producer());
     if (!m_playlist->is_valid()) {
         delete m_playlist;
-        m_playlist = 0;
+        m_playlist = nullptr;
         return;
     }
     if (m_playlist->count() > 0) {
@@ -735,7 +736,7 @@ void PlaylistModel::close()
     if (!m_playlist) return;
     clear();
     delete m_playlist;
-    m_playlist = 0;
+    m_playlist = nullptr;
     emit closed();
 }
 
