@@ -76,15 +76,18 @@ void SubtitlesModel::load(Mlt::Producer *producer)
     m_tracks.clear();
     if (m_producer) {
         for (int i = 0; i < producer->filter_count(); i++) {
-            Mlt::Filter filter(producer->filter(i));
-            if (filter.is_valid() && !::qstrcmp(filter.get("mlt_service"), "subtitle_feed")
-                    && filter.property_exists("text")) {
+            QScopedPointer<Mlt::Filter> filter(producer->filter(i));
+            if (!filter || !filter->is_valid()) {
+                continue;
+            }
+            if (!::qstrcmp(filter->get("mlt_service"), "subtitle_feed")
+                    && filter->property_exists("text")) {
                 SubtitleTrack track;
-                track.name = QString::fromUtf8(filter.get("feed"));
-                track.lang = QString::fromUtf8(filter.get("lang"));
+                track.name = QString::fromUtf8(filter->get("feed"));
+                track.lang = QString::fromUtf8(filter->get("lang"));
                 m_tracks.push_back(track);
                 m_items.resize(m_tracks.size());
-                Subtitles::SubtitleVector items = Subtitles::readFromSrtString(filter.get("text"));
+                Subtitles::SubtitleVector items = Subtitles::readFromSrtString(filter->get("text"));
                 m_items[m_items.size() - 1] = QList(items.cbegin(), items.cend());
             }
         }
@@ -177,7 +180,7 @@ void SubtitlesModel::commitToFeed(int trackIndex)
         if (!filter || !filter->is_valid()) {
             continue;
         }
-        if (filter->get("mlt_service") == QString("subtitle_feed")) {
+        if (filter->get("mlt_service") == QStringLiteral("subtitle_feed")) {
             if (feedFilterIndex == trackIndex) {
                 Subtitles::SubtitleVector items(m_items[trackIndex].constBegin(), m_items[trackIndex].constEnd());
                 std::string text;
@@ -315,6 +318,29 @@ void SubtitlesModel::importSubtitles(int trackIndex, int64_t msTime,
     MAIN.undoStack()->push(command);
 }
 
+void SubtitlesModel::importSubtitlesToNewTrack(SubtitlesModel::SubtitleTrack &track,
+                                               QList<Subtitles::SubtitleItem> &items)
+{
+    if (!m_producer) {
+        LOG_DEBUG() << "No producer";
+        return;
+    }
+
+    int trackIndex = m_tracks.size();
+
+    MAIN.undoStack()->beginMacro(QObject::tr("Import %1 subtitle items").arg(items.size()));
+
+    Subtitles::InsertTrackCommand *trackCommand = new Subtitles::InsertTrackCommand(*this, track,
+                                                                                    trackIndex);
+    MAIN.undoStack()->push(trackCommand);
+
+    Subtitles::OverwriteSubtitlesCommand *overwriteCommand = new Subtitles::OverwriteSubtitlesCommand(
+        *this, trackIndex, items);
+    MAIN.undoStack()->push(overwriteCommand);
+
+    MAIN.undoStack()->endMacro();
+}
+
 void SubtitlesModel::exportSubtitles(const QString &filePath, int trackIndex) const
 {
     if (!m_producer) {
@@ -516,7 +542,7 @@ void SubtitlesModel::doRemoveTrack(int trackIndex)
         if (!filter || !filter->is_valid()) {
             continue;
         }
-        if (filter->get("mlt_service") == QString("subtitle_feed")) {
+        if (filter->get("mlt_service") == QStringLiteral("subtitle_feed")) {
             if (feedFilterIndex == trackIndex) {
                 m_producer->detach(*filter);
                 break;
@@ -540,14 +566,14 @@ void SubtitlesModel::doEditTrack(const SubtitlesModel::SubtitleTrack &track, int
         QScopedPointer<Mlt::Filter> filter(m_producer->filter(i));
         if (filter && filter->is_valid()) {
             QString mlt_service = filter->get("mlt_service");
-            if (mlt_service == QString("subtitle_feed")) {
+            if (mlt_service == QStringLiteral("subtitle_feed")) {
                 filterIndex++;
                 if (filterIndex == trackIndex) {
                     filter->set("feed", track.name.toUtf8().constData());
                     filter->set("lang", track.lang.toUtf8().constData());
                     break;
                 }
-            } else if (mlt_service == QString("subtitle")) {
+            } else if (mlt_service == QStringLiteral("subtitle")) {
                 // Modify subtitle burn-in filter if present
                 if (filter->get("feed") == QString(m_tracks[trackIndex].name)) {
                     filter->set("feed", track.name.toUtf8().constData());
