@@ -37,6 +37,14 @@
 #define SEEK_INACTIVE (-1)
 #define VOLUME_SLIDER_HEIGHT (300)
 
+class NoWheelTabBar : public QTabBar
+{
+    void wheelEvent(QWheelEvent *event)
+    {
+        event->ignore();
+    };
+};
+
 QString blankTime()
 {
     switch (Settings.timeFormat()) {
@@ -80,7 +88,7 @@ Player::Player(QWidget *parent)
     vlayout->setSpacing(4);
 
     // Add tab bar to indicate/select what is playing: clip, playlist, timeline.
-    m_tabs = new QTabBar;
+    m_tabs = new NoWheelTabBar;
     m_tabs->setShape(QTabBar::RoundedSouth);
     m_tabs->setUsesScrollButtons(false);
     m_tabs->addTab(tr("Source"));
@@ -90,7 +98,7 @@ Player::Player(QWidget *parent)
     QHBoxLayout *tabLayout = new QHBoxLayout;
     tabLayout->setSpacing(8);
     tabLayout->addWidget(m_tabs);
-    connect(m_tabs, SIGNAL(tabBarClicked(int)), SLOT(onTabBarClicked(int)));
+    connect(m_tabs, &QTabBar::tabBarClicked, this, &Player::onTabBarClicked);
 
     // Add status bar.
     m_statusLabel = new StatusLabelWidget();
@@ -1004,12 +1012,18 @@ void Player::onDurationChanged()
 
 void Player::onFrameDisplayed(const SharedFrame &frame)
 {
-    if (MLT.producer() && MLT.producer()->get_length() != m_duration) {
+    if (!MLT.producer() || !MLT.producer()->is_valid())
+        return;
+
+    if (MLT.producer()->get_length() != m_duration) {
         // This can happen if the profile changes. Reload the properties from the producer.
         onProducerOpened(false);
     }
     int position = frame.get_position();
     bool loop = position >= (m_loopEnd - 1) && Actions["playerLoopAction"]->isChecked();
+    if (position > MLT.producer()->get_length()) {
+        position = MLT.producer()->get_length();
+    }
     if (position <= m_duration) {
         m_position = position;
         m_positionSpinner->blockSignals(true);
@@ -1350,7 +1364,7 @@ static inline float IEC_dB ( float fScale )
 void Player::onVolumeChanged(int volume)
 {
     const double gain = setVolume(volume);
-    emit showStatusMessage(QString("%L1 dB").arg(IEC_dB(gain)));
+    emit showStatusMessage(QStringLiteral("%L1 dB").arg(IEC_dB(gain)));
     Settings.setPlayerVolume(volume);
     Settings.setPlayerMuted(false);
     m_muteButton->setChecked(false);
