@@ -1,7 +1,7 @@
 /****************************************************************************
 **
 ** Copyright (C) 2016 The Qt Company Ltd.
-** Copyright (c) 2020-2023 Meltytech, LLC
+** Copyright (c) 2020-2024 Meltytech, LLC
 **
 ** Redistribution and use in source and binary forms, with or without
 ** modification, are permitted provided that the following conditions are
@@ -89,10 +89,12 @@ void QmlRichText::setFileUrl(const QUrl &arg)
                     setText(QStringLiteral("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">"
                                            "<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">"
                                            "p, li { white-space: pre-wrap; }"
-#ifdef Q_OS_WIN
-                                           "body { font-family:Verdana; font-size:72pt; font-weight:600; font-style:normal; color:#ffffff; }"
+#if defined(Q_OS_WIN)
+                                           "body { font-family:Verdana; font-size:72pt; font-weight:normal; font-style:normal; color:#ffffff; }"
+#elif defined(Q_OS_MAC)
+                                           "body { font-family:Helvetica; font-size:72pt; font-weight:normal; font-style:normal; color:#ffffff; }"
 #else
-                                           "body { font-family:sans-serif; font-size:72pt; font-weight:600; font-style:normal; color:#ffffff; }"
+                                           "body { font-family:sans-serif; font-size:72pt; font-weight:normal; font-style:normal; color:#ffffff; }"
 #endif
                                            "</style></head><body>")
                             % QString(decoder(data))
@@ -162,9 +164,9 @@ void QmlRichText::insertTable(int rows, int columns, int border)
         html += "<tr>";
         for (auto j = 0; j < columns; ++j) {
             if (j == 0) {
-                html += QString("<td>%1 %2</td>").arg(tr("Row")).arg(i + 1);
+                html += QStringLiteral("<td>%1 %2</td>").arg(tr("Row")).arg(i + 1);
             } else {
-                html += QString("<td>%1 %2</td>").arg(tr("Column")).arg(j + 1);
+                html += QStringLiteral("<td>%1 %2</td>").arg(tr("Column")).arg(j + 1);
             }
             if (border == 0 && j + 1 < columns) {
                 html += "<td width=5%></td>";
