@@ -35,6 +35,8 @@
 #include "settings.h"
 #include "models/metadatamodel.h"
 #include "models/keyframesmodel.h"
+#include "models/subtitlesmodel.h"
+#include "models/subtitlesselectionmodel.h"
 #include <QCoreApplication>
 #include <QSysInfo>
 #include <QCursor>
@@ -56,6 +58,8 @@ void QmlUtilities::registerCommonTypes()
     qmlRegisterType<QmlKeyframesParameter>("org.shotcut.qml", 1, 0, "Parameter");
     qmlRegisterType<QmlRichText>("org.shotcut.qml", 1, 0, "RichText");
     qmlRegisterType<KeyframesModel>("org.shotcut.qml", 1, 0, "KeyframesModel");
+    qmlRegisterType<SubtitlesModel>("org.shotcut.qml", 1, 0, "SubtitlesModel");
+    qmlRegisterType<SubtitlesSelectionModel>("org.shotcut.qml", 1, 0, "SubtitlesSelectionModel");
     qmlRegisterType<QmlUtilities>("org.shotcut.qml", 1, 0, "Utilities");
     // MetadataModel is registered to access its MetadataFilter enum.
     qmlRegisterUncreatableType<MetadataModel>("org.shotcut.qml", 1, 0, "MetadataModel",
