@@ -16,6 +16,9 @@
  */
 
 #include "settings.h"
+
+#include "qmltypes/qmlapplication.h"
+
 #include <QApplication>
 #include <QColor>
 #include <QLocale>
@@ -33,6 +36,7 @@ static QScopedPointer<ShotcutSettings> instance;
 static QString appDataForSession;
 static const int kMaximumTrackHeight = 125;
 static const QString kRecentKey("recent");
+static const QString kProjectsKey("projects");
 
 ShotcutSettings &ShotcutSettings::singleton()
 {
@@ -179,6 +183,30 @@ void ShotcutSettings::setRecent(const QStringList &ls)
         m_recent.setValue(kRecentKey, ls);
 }
 
+QStringList ShotcutSettings::projects()
+{
+    auto ls = m_recent.value(kProjectsKey).toStringList();
+    if (ls.isEmpty()) {
+        for (auto &r : recent()) {
+            if (r.endsWith(".mlt"))
+                ls << r;
+        }
+        // Prevent entering this block repeatedly
+        if (ls.isEmpty())
+            ls << QString();
+        setProjects(ls);
+    }
+    return ls;
+}
+
+void ShotcutSettings::setProjects(const QStringList &ls)
+{
+    if (ls.isEmpty())
+        m_recent.remove(kProjectsKey);
+    else if (!clearRecent())
+        m_recent.setValue(kProjectsKey, ls);
+}
+
 QString ShotcutSettings::theme() const
 {
     return settings.value("theme", "dark").toString();
@@ -612,6 +640,16 @@ void ShotcutSettings::setPlaylistAutoplay(bool b)
     settings.setValue("playlist/autoplay", b);
 }
 
+bool ShotcutSettings::playlistShowColumn(const QString &column)
+{
+    return settings.value("playlist/columns/" + column, true).toBool();
+}
+
+void ShotcutSettings::setPlaylistShowColumn(const QString &column, bool b)
+{
+    settings.setValue("playlist/columns/" + column, b);
+}
+
 bool ShotcutSettings::timelineDragScrub() const
 {
     return settings.value("timeline/dragScrub", false).toBool();
@@ -773,8 +811,10 @@ bool ShotcutSettings::timelineAutoAddTracks() const
 
 void ShotcutSettings::setTimelineAutoAddTracks(bool b)
 {
-    settings.setValue("timeline/autoAddTracks", b);
-    emit timelineAutoAddTracksChanged();
+    if (b != timelineAutoAddTracks()) {
+        settings.setValue("timeline/autoAddTracks", b);
+        emit timelineAutoAddTracksChanged();
+    }
 }
 
 bool ShotcutSettings::timelineRectangleSelect() const
@@ -943,6 +983,16 @@ void ShotcutSettings::setAskUpgradeAutomatic(bool b)
     settings.setValue("askUpgradeAutmatic", b);
 }
 
+bool ShotcutSettings::askChangeVideoMode()
+{
+    return settings.value("askChangeVideoMode", true).toBool();
+}
+
+void ShotcutSettings::setAskChangeVideoMode(bool b)
+{
+    settings.setValue("askChangeVideoMode", b);
+}
+
 void ShotcutSettings::sync()
 {
     settings.sync();
@@ -1004,20 +1054,20 @@ bool ShotcutSettings::setLayout(const QString &name, const QByteArray &geometry,
         layouts.append(name);
         settings.setValue("layout/layouts", layouts);
     }
-    settings.setValue(QString("layout/%1_%2").arg(name, "geometry"), geometry);
-    settings.setValue(QString("layout/%1_%2").arg(name, "state"), state);
+    settings.setValue(QStringLiteral("layout/%1_%2").arg(name, "geometry"), geometry);
+    settings.setValue(QStringLiteral("layout/%1_%2").arg(name, "state"), state);
     return isNew;
 }
 
 QByteArray ShotcutSettings::layoutGeometry(const QString &name)
 {
-    QString key = QString("layout/%1_geometry").arg(name);
+    QString key = QStringLiteral("layout/%1_geometry").arg(name);
     return settings.value(key).toByteArray();
 }
 
 QByteArray ShotcutSettings::layoutState(const QString &name)
 {
-    QString key = QString("layout/%1_state").arg(name);
+    QString key = QStringLiteral("layout/%1_state").arg(name);
     return settings.value(key).toByteArray();
 }
 
@@ -1031,8 +1081,8 @@ bool ShotcutSettings::removeLayout(const QString &name)
             settings.remove("layout/layouts");
         else
             settings.setValue("layout/layouts", list);
-        settings.remove(QString("layout/%1_%2").arg(name, "geometry"));
-        settings.remove(QString("layout/%1_%2").arg(name, "state"));
+        settings.remove(QStringLiteral("layout/%1_%2").arg(name, "geometry"));
+        settings.remove(QStringLiteral("layout/%1_%2").arg(name, "state"));
         return true;
     }
     return false;
@@ -1252,6 +1302,86 @@ void ShotcutSettings::setSlideshowTransitionSoftness(int transitionSoftness)
     settings.setValue("slideshow/transitionSoftness", transitionSoftness);
 }
 
+bool ShotcutSettings::keyframesDragScrub() const
+{
+    return settings.value("keyframes/dragScrub", false).toBool();
+}
+
+void ShotcutSettings::setKeyframesDragScrub(bool b)
+{
+    settings.setValue("keyframes/dragScrub", b);
+    emit keyframesDragScrubChanged();
+}
+
+void ShotcutSettings::setSubtitlesShowColumn(const QString &column, bool b)
+{
+    settings.setValue("subtitles/columns/" + column, b);
+}
+
+bool ShotcutSettings::subtitlesShowColumn(const QString &column) const
+{
+    return settings.value("subtitles/columns/" + column, true).toBool();
+}
+
+void ShotcutSettings::setSubtitlesTrackTimeline(bool b)
+{
+    settings.setValue("subtitles/trackTimeline", b);
+}
+
+bool ShotcutSettings::subtitlesTrackTimeline() const
+{
+    return settings.value("subtitles/trackTimeline", true).toBool();
+}
+
+void ShotcutSettings::setSubtitlesShowPrevNext(bool b)
+{
+    settings.setValue("subtitles/showPrevNext", b);
+}
+
+bool ShotcutSettings::subtitlesShowPrevNext() const
+{
+    return settings.value("subtitles/showPrevNext", true).toBool();
+}
+
+void ShotcutSettings::setWhisperExe(const QString &path)
+{
+    settings.setValue("subtitles/whisperExe", path);
+}
+
+QString ShotcutSettings::whisperExe()
+{
+    QDir dir(qApp->applicationDirPath());
+#if defined(Q_OS_WIN)
+    auto exe = "whisper.cpp-main.exe";
+#else
+    auto exe = "whisper.cpp-main";
+#endif
+    return settings.value("subtitles/whisperExe", dir.absoluteFilePath(exe)).toString();
+}
+
+void ShotcutSettings::setWhisperModel(const QString &path)
+{
+    settings.setValue("subtitles/whisperModel", path);
+}
+
+QString ShotcutSettings::whisperModel()
+{
+    QDir dataPath = QmlApplication::dataDir();
+    dataPath.cd("shotcut/whisper_models");
+    return settings.value("subtitles/whisperModel",
+                          dataPath.absoluteFilePath("ggml-base-q5_1.bin")).toString();
+}
+
+void ShotcutSettings::setNotesZoom(int zoom)
+{
+    settings.setValue("notes/zoom", zoom);
+}
+
+int ShotcutSettings::notesZoom() const
+{
+    return settings.value("notes/zoom", 0).toInt();
+}
+
 void ShotcutSettings::reset()
 {
     for (auto &key : settings.allKeys()) {
