@@ -71,6 +71,8 @@ class ShotcutSettings : public QObject
     Q_ENUMS(TimelineScrolling)
     Q_PROPERTY(bool timelineRectangleSelect READ timelineRectangleSelect WRITE
                setTimelineRectangleSelect NOTIFY timelineRectangleSelectChanged)
+    Q_PROPERTY(bool keyframesDragScrub READ keyframesDragScrub WRITE setKeyframesDragScrub
+               NOTIFY keyframesDragScrubChanged)
 
 public:
     static const qsizetype MaxPath {32767};
@@ -95,6 +97,8 @@ public:
     void setSavePath(const QString &);
     QStringList recent() const;
     void setRecent(const QStringList &);
+    QStringList projects();
+    void setProjects(const QStringList &);
     QString theme() const;
     void setTheme(const QString &);
     QThread::Priority jobPriority() const;
@@ -182,6 +186,8 @@ public:
     void setPlaylistThumbnails(const QString &);
     bool playlistAutoplay() const;
     void setPlaylistAutoplay(bool);
+    bool playlistShowColumn(const QString &);
+    void setPlaylistShowColumn(const QString &, bool);
 
     // timeline
     bool timelineDragScrub() const;
@@ -253,6 +259,8 @@ public:
     void setCheckUpgradeAutomatic(bool b);
     bool askUpgradeAutomatic();
     void setAskUpgradeAutomatic(bool b);
+    bool askChangeVideoMode();
+    void setAskChangeVideoMode(bool b);
 
     void sync();
     QString appDataLocation() const;
@@ -317,6 +325,26 @@ public:
     int slideshowTransitionSoftness(int defaultTransitionSoftness) const;
     void setSlideshowTransitionSoftness(int transitionSoftness);
 
+    // Keyframes
+    bool keyframesDragScrub() const;
+    void setKeyframesDragScrub(bool);
+
+    // Subtitles
+    void setSubtitlesShowColumn(const QString &column, bool b);
+    bool subtitlesShowColumn(const QString &column) const;
+    void setSubtitlesTrackTimeline(bool b);
+    bool subtitlesTrackTimeline() const;
+    void setSubtitlesShowPrevNext(bool b);
+    bool subtitlesShowPrevNext() const;
+    void setWhisperExe(const QString &path);
+    QString whisperExe();
+    void setWhisperModel(const QString &path);
+    QString whisperModel();
+
+    // Notes
+    void setNotesZoom(int zoom);
+    int notesZoom() const;
+
 public slots:
     void reset();
 
@@ -346,6 +374,7 @@ signals:
     void timelineAutoAddTracksChanged();
     void timelineRectangleSelectChanged();
     void timeFormatChanged();
+    void keyframesDragScrubChanged();
 
 private:
     explicit ShotcutSettings();
