@@ -342,7 +342,7 @@ QTemporaryFile *Util::writableTemporaryFile(const QString &filePath, const QStri
     // filePath should already be checked writable.
     QFileInfo info(filePath);
     QString templateFileName = templateName.isEmpty() ?
-                               QString("%1.XXXXXX").arg(QCoreApplication::applicationName()) : templateName;
+                               QStringLiteral("%1.XXXXXX").arg(QCoreApplication::applicationName()) : templateName;
 
     // First, try the system temp dir.
     QString templateFilePath = QDir(QDir::tempPath()).filePath(templateFileName);
@@ -396,12 +396,12 @@ void Util::applyCustomProperties(Mlt::Producer &destination, Mlt::Producer &sour
     QString resource = ProxyManager::resource(destination);
     if (!qstrcmp("timewarp", source.get("mlt_service"))) {
         auto speed = qAbs(source.get_double("warp_speed"));
-        auto caption = QString("%1 (%2x)").arg(Util::baseName(resource, true)).arg(speed);
+        auto caption = QStringLiteral("%1 (%2x)").arg(Util::baseName(resource, true)).arg(speed);
         destination.set(kShotcutCaptionProperty, caption.toUtf8().constData());
 
         resource = destination.get("_shotcut:resource");
         destination.set("warp_resource", resource.toUtf8().constData());
-        resource = QString("%1:%2:%3").arg("timewarp", source.get("warp_speed"), resource);
+        resource = QStringLiteral("%1:%2:%3").arg("timewarp", source.get("warp_speed"), resource);
         destination.set("resource", resource.toUtf8().constData());
         double speedRatio = 1.0 / speed;
         int length = qRound(destination.get_length() * speedRatio);
@@ -506,7 +506,7 @@ bool Util::isMemoryLow()
         }
     }
     return false;
-#elif defined(__FreeBSD__)
+#elif defined(__FreeBSD__) || defined(__OpenBSD__)
     QProcess p;
     p.start("sysctl -n hw.usermem");
     p.waitForFinished();
@@ -587,6 +587,9 @@ void Util::normalizeFrameRate(double fps, int &numerator, int &denominator)
         // Workaround storing QDoubleSpinBox::value() loses precision.
         numerator = qRound(fps * 1000000.0);
         denominator = 1000000;
+        auto gcd = greatestCommonDivisor(numerator, denominator);
+        numerator /= gcd;
+        denominator /= gcd;
     }
 }
 
@@ -678,7 +681,7 @@ QString Util::updateCaption(Mlt::Producer *producer)
     if (caption.isEmpty() || caption.startsWith(name)) {
         // compute the caption
         if (warpSpeed != 1.0)
-            caption = QString("%1 (%2x)").arg(name).arg(warpSpeed);
+            caption = QStringLiteral("%1 (%2x)").arg(name).arg(warpSpeed);
         else
             caption = name;
         producer->set(kShotcutCaptionProperty, caption.toUtf8().constData());
@@ -777,6 +780,9 @@ QString Util::trcString(int trc)
     case 11:
         trcString = "IEC 61966-2-4";
         break;
+    case 13:
+        trcString = "sRGB";
+        break;
     case 14:
         trcString = "ITU-R BT.2020";
         break;
@@ -799,7 +805,7 @@ QString Util::trcString(int trc)
 bool Util::trcIsCompatible(int trc)
 {
     // Transfer characteristics > SMPTE240M Probably need conversion except IEC61966-2-4 is OK
-    return trc <= 7 || trc == 11 || trc == 18;
+    return trc <= 7 || trc == 11 || trc == 13 || trc == 18;
 }
 
 QString Util::getConversionAdvice(Mlt::Producer *producer)
@@ -852,7 +858,33 @@ void Util::offerSingleFileConversion(QString &message, Mlt::Producer *producer,
                 producer->get_length() - 1;
     dialog.setSubClipChecked(producer->get_in() > 0
                              || producer->get_out() < producer->get_length() - 1);
+    auto fps = Util::getAndroidFrameRate(producer);
+    if (fps > 0.0)
+        dialog.setFrameRate(fps);
     Transcoder transcoder;
     transcoder.addProducer(producer);
     transcoder.convert(dialog);
 }
+
+double Util::getAndroidFrameRate(Mlt::Producer *producer)
+{
+    auto fps = producer->get_double("meta.attr.com.android.capture.fps.markup");
+    if (!qIsFinite(fps))
+        fps = 0.0;
+    return fps;
+}
+
+double Util::getSuggestedFrameRate(Mlt::Producer *producer)
+{
+    auto fps = producer->get_double("meta.attr.com.android.capture.fps.markup");
+    if (!qIsFinite(fps))
+        fps = 0.0;
+    if (fps <= 0.0) {
+        fps = producer->get_double("meta.media.frame_rate_num");
+        if (producer->get_double("meta.media.frame_rate_den") > 0)
+            fps /= producer->get_double("meta.media.frame_rate_den");
+        if (producer->get("force_fps"))
+            fps = producer->get_double("fps");
+    }
+    return fps;
+}
