@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2015-2022 Meltytech, LLC
+ * Copyright (c) 2015-2023 Meltytech, LLC
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,11 +20,11 @@
 #include "mltcontroller.h"
 #include "util.h"
 #include "settings.h"
-#include <QCameraInfo>
+#include <QMediaDevices>
+#include <QCameraDevice>
 #include <QCamera>
 #include <QString>
-#include <QAudioDeviceInfo>
-#include <QDesktopWidget>
+#include <QAudioDevice>
 #include "shotcut_mlt_properties.h"
 #include <Logger.h>
 
@@ -39,22 +39,22 @@ AvfoundationProducerWidget::AvfoundationProducerWidget(QWidget *parent) :
 
 #ifdef Q_OS_MAC
     auto currentVideo = 1;
-    for (const auto &cameraInfo : QCameraInfo::availableCameras()) {
+    for (const auto &cameraInfo : QMediaDevices::videoInputs()) {
         if (Settings.videoInput() == cameraInfo.description()) {
             currentVideo = ui->videoCombo->count();
         }
-        ui->videoCombo->addItem(cameraInfo.description(), cameraInfo.deviceName().toLocal8Bit());
+        ui->videoCombo->addItem(cameraInfo.description(), cameraInfo.id());
     }
 #if ENABLE_SCREEN_CAPTURE
-    for (int i = 0; i < QApplication::desktop()->screenCount(); i++)
-        ui->videoCombo->addItem(QString("Capture screen %1").arg(i));
+    for (int i = 0; i < QGuiApplication::screens().size(); i++)
+        ui->videoCombo->addItem(QStringLiteral("Capture screen %1").arg(i));
 #endif
     auto currentAudio = 1;
-    for (const auto &deviceInfo : QAudioDeviceInfo::availableDevices(QAudio::AudioInput)) {
-        if (Settings.audioInput() == deviceInfo.deviceName()) {
+    for (const auto &deviceInfo : QMediaDevices::audioInputs()) {
+        if (Settings.audioInput() == deviceInfo.description()) {
             currentAudio = ui->audioCombo->count();
         }
-        ui->audioCombo->addItem(deviceInfo.deviceName());
+        ui->audioCombo->addItem(deviceInfo.description());
     }
     if (ui->videoCombo->count() > 1)
         ui->videoCombo->setCurrentIndex(currentVideo);
@@ -76,20 +76,21 @@ Mlt::Producer *AvfoundationProducerWidget::newProducer(Mlt::Profile &profile)
     QSize size {1280, 720};
     Util::cameraFrameRateSize(ui->videoCombo->currentData().toByteArray(), frameRate, size);
     if (ui->videoCombo->currentIndex()) {
-        resource = QString("avfoundation:%1:%2?pixel_format=yuyv422&framerate=%3&video_size=%4x%5")
+        resource = QStringLiteral("avfoundation:%1:%2?pixel_format=yuyv422&framerate=%3&video_size=%4x%5")
                    .arg(ui->videoCombo->currentText().replace(tr("None"), "none"))
                    .arg(ui->audioCombo->currentText().replace(tr("None"), "none"))
                    .arg(frameRate).arg(size.width()).arg(size.height());
     } else {
-        resource = QString("avfoundation:none:%1").arg(ui->audioCombo->currentText().replace(tr("None"),
-                                                                                             "none"));
+        resource = QStringLiteral("avfoundation:none:%1").arg(ui->audioCombo->currentText().replace(
+                                                                  tr("None"),
+                                                                  "none"));
     }
     LOG_DEBUG() << resource;
     Mlt::Producer *p = new Mlt::Producer(profile, resource.toUtf8().constData());
     if (!p || !p->is_valid()) {
         delete p;
         p = new Mlt::Producer(profile, "color:");
-        p->set("resource", QString("avfoundation:%1:%2")
+        p->set("resource", QStringLiteral("avfoundation:%1:%2")
                .arg(ui->videoCombo->currentText().replace(tr("None"), "none"))
                .arg(ui->audioCombo->currentText())
                .toUtf8().constData());
