@@ -445,8 +445,8 @@ void SlideshowGeneratorWidget::applyLumaTransitionProperties(Mlt::Transition *lu
         luma->set("resource", "");
         luma->set("softness", 0);
     } else if (index <= 24) {
-        luma->set("resource", QString("%luma%1.pgm").arg(index - 2, 2, 10,
-                                                         QChar('0')).toLatin1().constData());
+        luma->set("resource", QStringLiteral("%luma%1.pgm").arg(index - 2, 2, 10,
+                                                                QChar('0')).toLatin1().constData());
         luma->set("softness", config.transitionSoftness / 100.0);
     } else {
         luma->set("resource", m_transitionStyleCombo->itemData(index).toString().toUtf8().constData());
@@ -479,7 +479,7 @@ void SlideshowGeneratorWidget::on_parameterChanged()
     }
 
     m_preview->stop();
-    m_preview->showText(Settings.playerGPU() ? tr("Preview Not Available") :
+    m_preview->showText(Settings.playerGPU() ? tr("Preview is not available with GPU Effects") :
                         tr("Generating Preview..."));
     m_mutex.lock();
     m_refreshPreview = true;
